@@ -15,7 +15,7 @@ class OpenProject:
     # 2a
     @staticmethod
     def open_data():
-        Ui_tools.click_on('\static\2a.png')
+        Ui_tools.click_on('\static\\2a.png')
 
     # 2b
     @staticmethod
@@ -30,6 +30,7 @@ class OpenProject:
     # 2d
     @staticmethod
     def input_file():
+        # TODO make as input parameter
         Ui_tools.type("nowyou-test-grafis")
 
     @staticmethod
